"""
Face Detect
By: Henry
"""

import cv2
import mediapipe as mp


class FaceDetector:
    def __init__(self, detectionCon=0.5):
        self.detectionCon = detectionCon
        self.mpFaces = mp.solutions.face_detection
        self.faces = self.mpFaces.FaceDetection(self.detectionCon)
        self.mpDraw = mp.solutions.drawing_utils
        self.mpFmesh = mp.solutions.face_mesh
        self.fmesh = self.mpFmesh.FaceMesh()
        self.mpHand = mp.solutions.hands
        self.hand = self.mpHand.Hands()

    def findFaces(self, img, draw=True):
        imgRGB = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
        self.results = self.faces.process(imgRGB)
        if self.results.detections:
            for d in self.results.detections:
                box = d.location_data.relative_bounding_box
                h, w, c = img.shape
                x = int(box.xmin * w)
                y = int(box.ymin * h)
                width = int(box.width * w)
                height = int(box.height * h)
                return (x,y,width,height)

    def findHand(self, img, draw=True):
        imgRGB = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
        self.results = self.hand.process(imgRGB)
        if self.results.multi_hand_landmarks:
            for d in self.results.multi_hand_landmarks:
                if draw:
                    self.mpDraw.draw_landmarks(img, d, self.mpHand.HAND_CONNECTIONS)
        return img

    def findFace(self, img, draw=True):
        imgRGB = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
        self.results = self.fmesh.process(imgRGB)
        if self.results.multi_face_landmarks:
            for d in self.results.multi_face_landmarks:
                if draw:
                    self.mpDraw.draw_landmarks(img,d,self.mpFmesh.FACE_CONNECTIONS)
        return img


d = FaceDetector(detectionCon=0.5)


def detectFace(img):
    return d.findFace(img)


def detectHand(img):
    return d.findHand(img)


def main():
    cap = cv2.VideoCapture(0)
    while True:
        success, img = cap.read()
        img = detectFace(img)
        cv2.imshow("Image", img)
        cv2.waitKey(1)


if __name__ == "__main__":
    main()


import setuptools

setuptools.setup(
    name="tctm", # Replace with your own username  #自定义封装模块名与文件夹名相同
    version="0.0.2", #版本号，下次修改后再提交的话只需要修改当前的版本号就可以了
    author="henry", #作者
    author_email="enryh123@outlook.com", #邮箱
    description="test lib", #描述
    long_description='test lib', #描述
    long_description_content_type="text/markdown", #markdown
    url="", #github地址
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License", #License
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.7"
)